.. SPDX-FileCopyrightText: Copyright © 2024 Idiap Research Institute <contact@idiap.ch>
..
.. SPDX-License-Identifier: GPL-3.0-or-later

.. _mednet.databases.detect.shenzhen:

===================
 Shenzhen Hospital
===================

* DataModule and support code: :py:mod:`.data.detect.shenzhen`
* Splits:

  .. list-table::
     :align: left

     * - Config. key
       - Module
     * - ``shenzhen-detect``
       - :py:mod:`.config.detect.data.shenzhen.default`
